@@ -1,10 +1,13 @@
 """Module for accessing KLF 200 gateway with python."""
 
+from .discovery import VeluxDiscovery
 from .exception import PyVLXException
 from .klf200gateway import Klf200Gateway
 from .lightening_device import Light, LighteningDevice
 from .log import PYVLXLOG
+from .node import Node
 from .nodes import Nodes
+from .on_off_switch import OnOffSwitch
 from .opening_device import (
     Awning, Blade, Blind, GarageDoor, Gate, OpeningDevice, RollerShutter,
     Window)
