@@ -9,7 +9,7 @@ class FrameGetStateRequest(FrameBase):
 
     PAYLOAD_LEN = 0
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Init Frame."""
         super().__init__(Command.GW_GET_STATE_REQ)
 
@@ -21,26 +21,26 @@ class FrameGetStateConfirmation(FrameBase):
 
     def __init__(
             self,
-            gateway_state=GatewayState.TEST_MODE,
-            gateway_sub_state=GatewaySubState.IDLE,
+            gateway_state: GatewayState = GatewayState.TEST_MODE,
+            gateway_sub_state: GatewaySubState = GatewaySubState.IDLE,
     ):
         """Init Frame."""
         super().__init__(Command.GW_GET_STATE_CFM)
         self.gateway_state = gateway_state
         self.gateway_sub_state = gateway_sub_state
 
-    def get_payload(self):
+    def get_payload(self) -> bytes:
         """Return Payload."""
         payload = bytes([self.gateway_state.value, self.gateway_sub_state.value])
         payload += bytes(4)  # State date, reserved for future use
         return payload
 
-    def from_payload(self, payload):
+    def from_payload(self, payload: bytes) -> None:
         """Init frame from binary data."""
         self.gateway_state = GatewayState(payload[0])
         self.gateway_sub_state = GatewaySubState(payload[1])
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{} gateway_state="{}" gateway_sub_state="{}"/>'.format(
             type(self).__name__, self.gateway_state, self.gateway_sub_state
