@@ -12,7 +12,7 @@ class FrameSetUTCConfirmation(FrameBase):
 
     PAYLOAD_LEN = 0
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Init Frame."""
         super().__init__(Command.GW_SET_UTC_CFM)
 
@@ -22,24 +22,24 @@ class FrameSetUTCRequest(FrameBase):
 
     PAYLOAD_LEN = 4
 
-    def __init__(self, timestamp=0):
+    def __init__(self, timestamp: float = 0):
         """Init Frame."""
         super().__init__(Command.GW_SET_UTC_REQ)
         self.timestamp = timestamp
 
     @property
-    def timestamp_formatted(self):
+    def timestamp_formatted(self) -> str:
         """Return time as human readable string."""
         return datetime.fromtimestamp(self.timestamp).strftime("%Y-%m-%d %H:%M:%S")
 
-    def get_payload(self):
+    def get_payload(self) -> bytes:
         """Return Payload."""
         return struct.pack(">I", self.timestamp)
 
-    def from_payload(self, payload):
+    def from_payload(self, payload: bytes) -> None:
         """Init frame from binary data."""
         self.timestamp = struct.unpack(">I", payload[0:4])[0]
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{} time="{}"/>'.format(type(self).__name__, self.timestamp_formatted)
