@@ -1,23 +1,28 @@
 """Module for retrieving scene list from API."""
+from typing import TYPE_CHECKING, List, Optional, Tuple
+
 from pyvlx.log import PYVLXLOG
 
 from .api_event import ApiEvent
 from .frames import (
-    FrameGetSceneListConfirmation, FrameGetSceneListNotification,
+    FrameBase, FrameGetSceneListConfirmation, FrameGetSceneListNotification,
     FrameGetSceneListRequest)
 
+if TYPE_CHECKING:
+    from pyvlx import PyVLX
+
 
 class GetSceneList(ApiEvent):
     """Class for retrieving scene list from API."""
 
-    def __init__(self, pyvlx):
+    def __init__(self, pyvlx: "PyVLX"):
         """Initialize SceneList class."""
         super().__init__(pyvlx=pyvlx)
         self.success = False
-        self.count_scenes = None
-        self.scenes = []
+        self.count_scenes: Optional[int] = None
+        self.scenes: List[Tuple[int, str]] = []
 
-    async def handle_frame(self, frame):
+    async def handle_frame(self, frame: FrameBase) -> bool:
         """Handle incoming API frame, return True if this was the expected frame."""
         if isinstance(frame, FrameGetSceneListConfirmation):
             self.count_scenes = frame.count_scenes
@@ -39,6 +44,6 @@ class GetSceneList(ApiEvent):
             return True
         return False
 
-    def request_frame(self):
+    def request_frame(self) -> FrameGetSceneListRequest:
         """Construct initiating frame."""
         return FrameGetSceneListRequest()
